@@ -2,17 +2,17 @@ source("helpers.R")
 using("tinysnapshot")
 
 # Bug: \begin{table}[H][H]
-options(tinytable_theme_placement_latex_float = "H")
+options(tinytable_latex_placement = "H")
 x <- mtcars[1:4, 1:4]
-tab <- tt(x) |> theme_tt("resize", width = .9)
+tab <- tt(x) |> theme_latex(resize_width = .9, resize_direction = "down")
 tab@output <- "latex"
 expect_snapshot_print(tab, label = "theme-placement_options_no_doubling")
-options(tinytable_theme_placement_latex_float = "H")
+options(tinytable_latex_placement = "H")
 
 # Issue #206: resize with footnote
 k <- data.frame(X = 1) |>
   tt(note = "abc") |>
-  theme_tt(theme = "resize", width = 0.9) |>
+  theme_latex(resize_width = 0.9, resize_direction = "down") |>
   save_tt("latex")
 expect_inherits(k, "character")
 
@@ -29,7 +29,6 @@ theme_mitex <- function(x, ...) {
     return(table)
   }
   x <- style_tt(x, finalize = fn)
-  x <- theme_tt(x, theme = "default")
   return(x)
 }
 tab <- data.frame(Math = c("$\\alpha$", "$a_{it}$", "$e^{i\\pi} + 1 = 0$")) |>
@@ -42,6 +41,22 @@ expect_inherits(tab, "character")
 tmp <- rbind(mtcars, mtcars)[, 1:6]
 cap <- "A long 80\\% width table with repeating headers."
 tab <- tt(tmp, width = .8, caption = cap) |>
-  theme_tt("multipage", rowhead = 1) |>
+  theme_latex(multipage = TRUE, rowhead = 1) |>
   save_tt("latex")
 expect_true(grepl("rowhead=1", tab))
+
+
+# theme_tt() deprecation warning
+expect_warning(theme_tt(tt(head(iris)), "striped"), pattern = "deprecated")
+
+
+# Issue #531: style_tt() overrides triped theme
+iris_dt <- do.call(rbind, by(iris, ~Species, head, 2))
+cap <- "Colors in first column should apply in both odd and even rows."
+tab <- tt(iris_dt, theme = "striped", caption = cap) |>
+  style_tt(i = 1:2, j = 1, color = "white", background = "#4B0055") |>
+  style_tt(i = 3:4, j = 1, color = "white", background = "#009B95") |>
+  style_tt(i = 5:6, j = 1, color = "white", background = "#FDE333")
+expect_snapshot_print(
+  print_html(tab),
+  "theme-issue531_style_colors_override_stripes.html")
